import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { Tag } from 'ant-design-vue';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'title',
    label: '标题'
  },
  {
    component: 'Input',
    fieldName: 'assetno',
    label: '资产编号'
  },
  {
    component: 'RangePicker',
    fieldName: 'planTime',
    label: '保养日期'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.MAINT_ORDER_ST_STATUS)
    },
    fieldName: 'status',
    label: '状态'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '标题',
    field: 'title',
    minWidth: 200,
    fixed: 'left'
  },
  {
    title: '保养年月',
    field: 'planTime',
    minWidth: 120
  },
  {
    title: '状态',
    field: 'status',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return renderDict(row.status, DictEnum.MAINT_ORDER_ST_STATUS);
      }
    }
  },
  {
    title: '资产编号',
    field: 'assetNo',
    minWidth: 160
  },
  {
    title: '工单总数',
    field: 'orderCount',
    minWidth: 100
  },
  {
    title: '待保养',
    field: 'dbyCount',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return <Tag color="orange">{row.dbyCount}</Tag>;
      }
    }
  },
  {
    title: '保养中',
    field: 'byCount',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return <Tag color="blue">{row.byCount}</Tag>;
      }
    }
  },
  {
    title: '待验证',
    field: 'dyzCount',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return <Tag color="purple">{row.dyzCount}</Tag>;
      }
    }
  },
  {
    title: '完成',
    field: 'wcCount',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return <Tag color="success">{row.wcCount}</Tag>;
      }
    }
  },
  {
    title: '特记事项',
    field: 'specialNote',
    minWidth: 160
  },
  {
    title: '保养成员',
    field: 'maintUserNames',
    minWidth: 160
  },
  {
    title: '稽查时间',
    field: 'verifyTime',
    minWidth: 200
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'equId'
  },
  {
    component: 'DatePicker',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'planTime',
    label: '计划保养日期'
  },
  {
    component: 'Input',
    componentProps: {
      readonly: true
    },
    fieldName: 'title',
    label: '标题'
  },
  {
    component: 'Textarea',
    fieldName: 'specialNote',
    label: '特记事项'
  },
  {
    component: 'Input',
    fieldName: 'verifyUser',
    label: '稽查人',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'verifyUserName',
    label: '稽查人'
  },
  {
    component: 'Textarea',
    fieldName: 'remark',
    label: '备注'
  }
];
